@@ -1,4 +1,4 @@
-/* $Id: initterm-r0drv-linux.c 135976 2020-02-04 10:35:17Z bird $ */
+/* $Id: initterm-r0drv-linux.c 139853 2020-08-11 19:53:38Z bird $ */
 /** @file
  * IPRT - Initialization & Termination, R0 Driver, Linux.
  */
@@ -39,7 +39,7 @@
 *   Global Variables                                                                                                             *
 *********************************************************************************************************************************/
 /** The IPRT work queue. */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
+#if RTLNX_VER_MIN(2,5,41)
 static struct workqueue_struct *g_prtR0LnxWorkQueue;
 #else
 static DECLARE_TASK_QUEUE(g_rtR0LnxWorkQueue);
@@ -57,8 +57,8 @@ DECLHIDDEN(void) rtR0LnxWorkqueuePush(RTR0LNXWORKQUEUEITEM *pWork, void (*pfnWor
 {
     IPRT_LINUX_SAVE_EFL_AC();
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
-# if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 20)
+#if RTLNX_VER_MIN(2,5,41)
+# if RTLNX_VER_MIN(2,6,20)
     INIT_WORK(pWork, pfnWorker);
 # else
     INIT_WORK(pWork, (void (*)(void *))pfnWorker, pWork);
@@ -83,7 +83,7 @@ DECLHIDDEN(void) rtR0LnxWorkqueueFlush(void)
 {
     IPRT_LINUX_SAVE_EFL_AC();
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
+#if RTLNX_VER_MIN(2,5,41)
     flush_workqueue(g_prtR0LnxWorkQueue);
 #else
     run_task_queue(&g_rtR0LnxWorkQueue);
@@ -98,8 +98,8 @@ DECLHIDDEN(int) rtR0InitNative(void)
     int rc = VINF_SUCCESS;
     IPRT_LINUX_SAVE_EFL_AC();
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
- #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 13)
+#if RTLNX_VER_MIN(2,5,41)
+ #if RTLNX_VER_MIN(2,6,13)
     g_prtR0LnxWorkQueue = create_workqueue("iprt-VBoxWQueue");
  #else
     g_prtR0LnxWorkQueue = create_workqueue("iprt-VBoxQ");
@@ -118,7 +118,7 @@ DECLHIDDEN(void) rtR0TermNative(void)
     IPRT_LINUX_SAVE_EFL_AC();
 
     rtR0LnxWorkqueueFlush();
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
+#if RTLNX_VER_MIN(2,5,41)
     destroy_workqueue(g_prtR0LnxWorkQueue);
     g_prtR0LnxWorkQueue = NULL;
 #endif
