@@ -1,4 +1,4 @@
-/* $Id: memobj-r0drv-linux.c 142337 2021-01-21 19:35:49Z bird $ */
+/* $Id: memobj-r0drv-linux.c 147244 2021-10-04 15:42:27Z bird $ */
 /** @file
  * IPRT - Ring-0 Memory Objects, Linux.
  */
@@ -825,6 +825,13 @@ DECLHIDDEN(int) rtR0MemObjNativeAllocPage(PPRTR0MEMOBJINTERNAL ppMem, size_t cb,
 }
 
 
+DECLHIDDEN(int) rtR0MemObjNativeAllocLarge(PPRTR0MEMOBJINTERNAL ppMem, size_t cb, size_t cbLargePage, uint32_t fFlags,
+                                           const char *pszTag)
+{
+    return rtR0MemObjFallbackAllocLarge(ppMem, cb, cbLargePage, fFlags, pszTag);
+}
+
+
 DECLHIDDEN(int) rtR0MemObjNativeAllocLow(PPRTR0MEMOBJINTERNAL ppMem, size_t cb, bool fExecutable)
 {
     IPRT_LINUX_SAVE_EFL_AC();
